Learn R Programming

TAM (version 2.4-9)

TAM-utilities: Utility Functions in TAM

Description

Utility functions in TAM.

Usage

## information about used package version
tam_packageinfo(pack)
## call statement in a string format	
tam_print_call(CALL)
## information about R session
tam_rsessinfo()
## grep list of arguments for a specific variable
tam_args_CALL_search(args_CALL, variable, default_value)

## base::matrix function with argument value byrow=TRUE tam_matrix2(x, nrow=NULL, ncol=NULL) ## more efficient base::outer functions for operations "*", "+" and "-" tam_outer(x, y, op="*") ## row normalization of a matrix tam_normalize_matrix_rows(x) ## row normalization of a vector tam_normalize_vector(x) ## aggregate function for mean and sum based on base::rowsum tam_aggregate(x, group, mean=FALSE, na.rm=TRUE) ## column index when a value in a matrix is exceeded (used in TAM::tam.pv) tam_interval_index(matr, rn) ## cumulative sum of row entries in a matrix tam_rowCumsums(matr)

## remove items or persons with complete missing entries tam_remove_missings( dat, items, elim_items=TRUE, elim_persons=TRUE ) ## compute AXsi given A and xsi tam_AXsi_compute(A, xsi) ## fit xsi given A and AXsi tam_AXsi_fit(A, AXsi)

## trimming increments in iterations tam_trim_increment(increment, max.increment, trim_increment="cut", trim_incr_factor = 2, eps = 1E-10, avoid_na = FALSE) ## numerical differentiation by central difference tam_difference_quotient(d0, d0p, d0m, h) ## assign elements of a list in an environment tam_assign_list_elements(x, envir)

Arguments

pack

An R package

CALL

An R call

args_CALL

Arguments obtained from as.list( sys.call() )

variable

Name of a variable

default_value

Default value of a variable

x

Vector or matrix or list

nrow

Number of rows

ncol

Number of columns

y

Vector

op

An operation "*", "+" or "-"

group

Vector of grouping identifiers

mean

Logical indicating whether mean should be calculated or the sum

na.rm

Logical indicating whether missing values should be removed

matr

Matrix

rn

Vector

dat

Data frame

items

Vector

elim_items

Logical

elim_persons

Logical

A

Array

xsi

Vector

AXsi

Matrix

increment

Vector

max.increment

Numeric

trim_increment

One of the methods "half" or "cut"

trim_incr_factor

Factor of trimming in method "half"

eps

Small number preventing from division by zero

avoid_na

Logical indicating whether missing values should be set to zero.

d0

Vector

d0p

Vector

d0m

Vector

h

Vector

envir

Environment variable