Learn R Programming

TAM (version 2.4-9)

tampv2datalist: Conversion of Plausible Value Object into Datalist

Description

Converts a tam.pv object and a matrix of covariates into a list of multiply imputed datasets. This list can be conveniently analyzed by R packages such as semTools, Zelig, mice or BIFIEsurvey.

Usage

tampv2datalist(tam.pv.object, pvnames = NULL, Y = NULL, Y.pid = "pid")

Arguments

tam.pv.object

Generated tam.pv object

pvnames

Variable names of generated plausible values

Y

Matrix with covariates

Y.pid

Person identifier in Y matrix. It is not required that a person identifier is provided. In this case, the merge of the datasets will be conducted as for rbind.

Value

List of multiply imputed datasets

See Also

For examples see tam.pv.